Feedforward Closedloop Learning: Member List

Feedforward Closedloop Learning

Layer Member List

This is the complete list of members for Layer, including all inherited members.

calcOutputs() | Layer |
doLearning() | Layer |
doNormaliseWeights() | Layer |
getError(int i) | Layer |
getNeuron(int index) | Layer | inline
getNinputs() | Layer | inline
getNneurons() | Layer | inline
getOutput(int index) | Layer | inline
getWeightDistanceFromInitialWeights() | Layer |
initWeights(double _max=1, int initBiasWeight=1, Neuron::WeightInitMethod weightInitMethod=Neuron::MAX_OUTPUT_RANDOM) | Layer |
Layer(int _nNeurons, int _nInputs) | Layer |
saveWeightMatrix(char *filename) | Layer |
setActivationFunction(Neuron::ActivationFunction _activationFunction) | Layer |
setBias(double _bias) | Layer |
setConvolution(int width, int height) | Layer |
setDebugInfo(int layerIndex) | Layer |
setDecay(double _decay) | Layer |
setError(double _error) | Layer |
setError(int i, double _error) | Layer |
setErrors(double *_errors) | Layer |
setInput(int inputIndex, double input) | Layer |
setInputs(double *_inputs) | Layer |
setLearningRate(double _learningRate) | Layer |
setMaxDetLayer(int _m) | Layer | inline
setMomentum(double _momentum) | Layer |
setNormaliseWeights(WeightNormalisation _normaliseWeights) | Layer |
setStep(long int step) | Layer |
setUseThreads(int _useThreads) | Layer | inline
WEIGHT_NORM_LAYER_EUCLEDIAN enum value (defined in Layer) | Layer |
WEIGHT_NORM_LAYER_INFINITY enum value (defined in Layer) | Layer |
WEIGHT_NORM_LAYER_MANHATTAN enum value (defined in Layer) | Layer |
WEIGHT_NORM_NEURON_EUCLEDIAN enum value (defined in Layer) | Layer |
WEIGHT_NORM_NEURON_INFINITY enum value (defined in Layer) | Layer |
WEIGHT_NORM_NEURON_MANHATTAN enum value (defined in Layer) | Layer |
WEIGHT_NORM_NONE enum value (defined in Layer) | Layer |
WeightNormalisation enum name | Layer |
~Layer() | Layer |